==> jcu.theme-1.5.4.tar.gz: jcu.theme-1.5.4/jcu/theme/tests/base.py <==
import unittest

from zope.testing import doctestunit
from zope.component import testing
from Testing import ZopeTestCase as ztc

from Products.Five import zcml
from Products.Five import fiveconfigure
from Products.PloneTestCase import PloneTestCase as ptc
from Products.PloneTestCase.layer import onsetup

# When ZopeTestCase configures Zope, it will *not* auto-load products
# in Products/. Instead, we have to use a statement such as:
#   ztc.installProduct('SimpleAttachment')
# This does *not* apply to products in eggs and Python packages (i.e.
# not in the Products.*) namespace. For that, see below.
# All of Plone's products are already set up by PloneTestCase.

@onsetup
def setup_product():
    """Set up the package and its dependencies.

    The @onsetup decorator causes the execution of this body to be
    deferred until the setup of the Plone site testing layer. We could
    have created our own layer, but this is the easiest way for Plone
    integration tests.
    """

    # Load the ZCML configuration for the example.tests package.
    # This can of course use <include /> to include other packages.

    fiveconfigure.debug_mode = True
    import plone.app.z3cform
    zcml.load_config('configure.zcml', plone.app.z3cform)
    import Products.Collage
    zcml.load_config('configure.zcml', Products.Collage)
    import collective.contentleadimage
    zcml.load_config('configure.zcml', collective.contentleadimage)
    import collective.fastview
    zcml.load_config('configure.zcml', collective.fastview)
    import jcu.theme
    zcml.load_config('configure.zcml', jcu.theme)
    fiveconfigure.debug_mode = False

    # We need to tell the testing framework that these products
    # should be available. This can't happen until after we have loaded
    # the ZCML. Thus, we do it here. Note the use of installPackage()
    # instead of installProduct().
    # This is *only* necessary for packages outside the Products.*
    # namespace which are also declared as Zope 2 products, using
    # <five:registerPackage /> in ZCML.

    ztc.installPackage('jcu.theme')

setup_product()

# no installer for the product yet, instead just install parent product
ptc.setupPloneSite(products=['plone.app.z3cform','Products.Collage','collective.contentleadimage','jcu.theme'])

class TestCase(ptc.PloneTestCase):
    """We use this base class for all the tests in this package. If
    necessary, we can put common utility or setup code in here. This
    applies to unit test cases.
    """
    pass


class FunctionalTestCase(ptc.FunctionalTestCase):
    """We use this class for functional integration tests that use
    doctest syntax. Again, we can put basic common utility or setup
    code in here.
    """
    pass

==> jcu.theme-1.5.6.tar.gz: jcu.theme-1.5.6/jcu/theme/tests/base.py <==
#import unittest

#from zope.testing import doctestunit
#from zope.component import testing
from Testing import ZopeTestCase as ztc

from Products.Five import zcml
from Products.Five import fiveconfigure
from Products.PloneTestCase import PloneTestCase as ptc
from Products.PloneTestCase.layer import onsetup

# When ZopeTestCase configures Zope, it will *not* auto-load products
# in Products/. Instead, we have to use a statement such as:
#   ztc.installProduct('SimpleAttachment')
# This does *not* apply to products in eggs and Python packages (i.e.
# not in the Products.*) namespace. For that, see below.
# All of Plone's products are already set up by PloneTestCase.


@onsetup
def setup_product():
    """Set up the package and its dependencies.

    The @onsetup decorator causes the execution of this body to be
    deferred until the setup of the Plone site testing layer. We could
    have created our own layer, but this is the easiest way for Plone
    integration tests.
    """

    # Load the ZCML configuration for the example.tests package.
    # This can of course use <include /> to include other packages.

    fiveconfigure.debug_mode = True
    #import plone.app.z3cform
    #zcml.load_config('configure.zcml', plone.app.z3cform)
    #import Products.Collage
    #zcml.load_config('configure.zcml', Products.Collage)
    #import collective.contentleadimage
    #zcml.load_config('configure.zcml', collective.contentleadimage)
    #import collective.fastview
    #zcml.load_config('configure.zcml', collective.fastview)
    import jcu.theme
    zcml.load_config('configure.zcml', jcu.theme)
    fiveconfigure.debug_mode = False

    # We need to tell the testing framework that these products
    # should be available. This can't happen until after we have loaded
    # the ZCML. Thus, we do it here. Note the use of installPackage()
    # instead of installProduct().
    # This is *only* necessary for packages outside the Products.*
    # namespace which are also declared as Zope 2 products, using
    # <five:registerPackage /> in ZCML.

    ztc.installPackage('jcu.theme')

setup_product()

# no installer for the product yet, instead just install parent product
ptc.setupPloneSite(products=['plone.app.z3cform',
                             'Products.Collage',
                             'collective.contentleadimage',
                             'jcu.theme'
                            ]
                  )


class TestCase(ptc.PloneTestCase):
    """We use this base class for all the tests in this package. If
    necessary, we can put common utility or setup code in here. This
    applies to unit test cases.
    """
    pass


class FunctionalTestCase(ptc.FunctionalTestCase):
    """We use this class for functional integration tests that use
    doctest syntax. Again, we can put basic common utility or setup
    code in here.
    """
    pass
